@@ -25,6 +25,7 @@ from pygmt.exceptions import (
     GMTInvalidInput,
     GMTVersionError,
 )
+from pygmt.helpers import data_kind, dummy_context
 
 FAMILIES = [
     "GMT_IS_DATASET",
@@ -171,7 +172,7 @@ class Session:
         """
         Create a GMT API session and check the libgmt version.
 
-        Calls :meth:`~gmt.clib.Session.create`.
+        Calls :meth:`pygmt.clib.Session.create`.
 
         Raises
         ------
@@ -197,7 +198,7 @@ class Session:
         """
         Destroy the currently open GMT API session.
 
-        Calls :meth:`~gmt.clib.Session.destroy`.
+        Calls :meth:`pygmt.clib.Session.destroy`.
         """
         self.destroy()
 
@@ -296,10 +297,10 @@ class Session:
 
         .. warning::
 
-            Usage of :class:`~gmt.clib.Session` as a context manager in a
+            Usage of :class:`pygmt.clib.Session` as a context manager in a
             ``with`` block is preferred over calling
-            :meth:`~gmt.clib.Session.create` and
-            :meth:`~gmt.clib.Session.destroy` manually.
+            :meth:`pygmt.clib.Session.create` and
+            :meth:`pygmt.clib.Session.destroy` manually.
 
         Calls ``GMT_Create_Session`` and generates a new ``GMTAPI_CTRL``
         struct, which is a :class:`ctypes.c_void_p` pointer. Sets the
@@ -387,10 +388,10 @@ class Session:
 
         .. warning::
 
-            Usage of :class:`~gmt.clib.Session` as a context manager in a
+            Usage of :class:`pygmt.clib.Session` as a context manager in a
             ``with`` block is preferred over calling
-            :meth:`~gmt.clib.Session.create` and
-            :meth:`~gmt.clib.Session.destroy` manually.
+            :meth:`pygmt.clib.Session.create` and
+            :meth:`pygmt.clib.Session.destroy` manually.
 
         Calls ``GMT_Destroy_Session`` to terminate and free the memory of a
         registered ``GMTAPI_CTRL`` session (the pointer for this struct is
@@ -631,7 +632,8 @@ class Session:
 
         If valid modifiers are not given, then will assume that modifiers are
         not allowed. In this case, will raise a
-        :class:`~gmt.exceptions.GMTInvalidInput` exception if given a modifier.
+        :class:`pygmt.exceptions.GMTInvalidInput` exception if given a
+        modifier.
 
         Parameters
         ----------
@@ -639,7 +641,7 @@ class Session:
             The name of a valid GMT API constant, with an optional modifier.
         valid : list of str
             A list of valid values for the constant. Will raise a
-            :class:`~gmt.exceptions.GMTInvalidInput` exception if the given
+            :class:`pygmt.exceptions.GMTInvalidInput` exception if the given
             value is not on the list.
         """
         parts = constant.split("|")
@@ -739,7 +741,7 @@ class Session:
         Use this function to attach numpy array data to a GMT dataset and pass
         it to GMT modules. Wraps ``GMT_Put_Vector``.
 
-        The dataset must be created by :meth:`~gmt.clib.Session.create_data`
+        The dataset must be created by :meth:`pygmt.clib.Session.create_data`
         first. Use ``family='GMT_IS_DATASET|GMT_VIA_VECTOR'``.
 
         Not at all numpy dtypes are supported, only: float64, float32, int64,
@@ -755,7 +757,7 @@ class Session:
         ----------
         dataset : :class:`ctypes.c_void_p`
             The ctypes void pointer to a ``GMT_Dataset``. Create it with
-            :meth:`~gmt.clib.Session.create_data`.
+            :meth:`pygmt.clib.Session.create_data`.
         column : int
             The column number of this vector in the dataset (starting from 0).
         vector : numpy 1d-array
@@ -802,7 +804,7 @@ class Session:
         Use this function to attach string type numpy array data to a GMT
         dataset and pass it to GMT modules. Wraps ``GMT_Put_Strings``.
 
-        The dataset must be created by :meth:`~gmt.clib.Session.create_data`
+        The dataset must be created by :meth:`pygmt.clib.Session.create_data`
         first.
 
         .. warning::
@@ -815,7 +817,7 @@ class Session:
         ----------
         dataset : :class:`ctypes.c_void_p`
             The ctypes void pointer to a ``GMT_Dataset``. Create it with
-            :meth:`~gmt.clib.Session.create_data`.
+            :meth:`pygmt.clib.Session.create_data`.
         family : str
             The family type of the dataset. Can be either ``GMT_IS_VECTOR`` or
             ``GMT_IS_MATRIX``.
@@ -862,7 +864,7 @@ class Session:
         Use this function to attach numpy array data to a GMT dataset and pass
         it to GMT modules. Wraps ``GMT_Put_Matrix``.
 
-        The dataset must be created by :meth:`~gmt.clib.Session.create_data`
+        The dataset must be created by :meth:`pygmt.clib.Session.create_data`
         first. Use ``|GMT_VIA_MATRIX'`` in the family.
 
         Not at all numpy dtypes are supported, only: float64, float32, int64,
@@ -877,7 +879,7 @@ class Session:
         ----------
         dataset : :class:`ctypes.c_void_p`
             The ctypes void pointer to a ``GMT_Dataset``. Create it with
-            :meth:`~gmt.clib.Session.create_data`.
+            :meth:`pygmt.clib.Session.create_data`.
         matrix : numpy 2d-array
             The array that will be attached to the dataset. Must be a 2d C
             contiguous array.
@@ -910,7 +912,7 @@ class Session:
         Write a GMT data container to a file.
 
         The data container should be created by
-        :meth:`~gmt.clib.Session.create_data`.
+        :meth:`pygmt.clib.Session.create_data`.
 
         Wraps ``GMT_Write_Data`` but only allows writing to a file. So the
         ``method`` argument is omitted.
@@ -936,7 +938,7 @@ class Session:
             The output file name.
         data : :class:`ctypes.c_void_p`
             Pointer to the data container created by
-            :meth:`~gmt.clib.Session.create_data`.
+            :meth:`pygmt.clib.Session.create_data`.
 
         Raises
         ------
@@ -981,7 +983,7 @@ class Session:
 
         GMT uses a virtual file scheme to pass in data to API modules. Use it
         to pass in your GMT data structure (created using
-        :meth:`~gmt.clib.Session.create_data`) to a module that expects an
+        :meth:`pygmt.clib.Session.create_data`) to a module that expects an
         input or output file.
 
         Use in a ``with`` block. Will automatically close the virtual file when
@@ -1096,9 +1098,9 @@ class Session:
         virtual file upon exit of the ``with`` block.
 
         Use this instead of creating the data container and virtual file by
-        hand with :meth:`~gmt.clib.Session.create_data`,
-        :meth:`~gmt.clib.Session.put_vector`, and
-        :meth:`~gmt.clib.Session.open_virtual_file`.
+        hand with :meth:`pygmt.clib.Session.create_data`,
+        :meth:`pygmt.clib.Session.put_vector`, and
+        :meth:`pygmt.clib.Session.open_virtual_file`.
 
         If the arrays are C contiguous blocks of memory, they will be passed
         without copying to GMT. If they are not (e.g., they are columns of a 2D
@@ -1206,12 +1208,12 @@ class Session:
 
         **Not meant for creating ``GMT_GRID``**. The grid requires more
         metadata than just the data matrix. Use
-        :meth:`~gmt.clib.Session.virtualfile_from_grid` instead.
+        :meth:`pygmt.clib.Session.virtualfile_from_grid` instead.
 
         Use this instead of creating the data container and virtual file by
-        hand with :meth:`~gmt.clib.Session.create_data`,
-        :meth:`~gmt.clib.Session.put_matrix`, and
-        :meth:`~gmt.clib.Session.open_virtual_file`
+        hand with :meth:`pygmt.clib.Session.create_data`,
+        :meth:`pygmt.clib.Session.put_matrix`, and
+        :meth:`pygmt.clib.Session.open_virtual_file`
 
         The matrix must be C contiguous in memory. If it is not (e.g., it is a
         slice of a larger array), the array will be copied to make sure it is.
@@ -1288,9 +1290,9 @@ class Session:
         metadata.
 
         Use this instead of creating a data container and virtual file by hand
-        with :meth:`~gmt.clib.Session.create_data`,
-        :meth:`~gmt.clib.Session.put_matrix`, and
-        :meth:`~gmt.clib.Session.open_virtual_file`
+        with :meth:`pygmt.clib.Session.create_data`,
+        :meth:`pygmt.clib.Session.put_matrix`, and
+        :meth:`pygmt.clib.Session.open_virtual_file`
 
         The grid data matrix must be C contiguous in memory. If it is not
         (e.g., it is a slice of a larger array), the array will be copied to
@@ -1358,6 +1360,107 @@ class Session:
         with self.open_virtual_file(*args) as vfile:
             yield vfile
 
+    def virtualfile_from_data(
+        self, check_kind=None, data=None, x=None, y=None, z=None, extra_arrays=None
+    ):
+        """
+        Store any data inside a virtual file.
+
+        This convenience function automatically detects the kind of data passed
+        into it, and produces a virtualfile that can be passed into GMT later
+        on.
+
+        Parameters
+        ----------
+        check_kind : str
+            Used to validate the type of data that can be passed in. Choose
+            from 'raster', 'vector' or None. Default is None (no validation).
+        data : str, xarray.DataArray, 2d array, or None
+            Any raster or vector data format. This could be a file name, a
+            raster grid, a vector matrix/arrays, or other supported data input.
+        x/y/z : 1d arrays or None
+            x, y and z columns as numpy arrays.
+        extra_arrays : list of 1d arrays
+            Optional. A list of numpy arrays in addition to x, y and z. All
+            of these arrays must be of the same size as the x/y/z arrays.
+
+        Returns
+        -------
+        file_context : contextlib._GeneratorContextManager
+            The virtual file stored inside a context manager. Access the file
+            name of this virtualfile using ``with file_context as fname: ...``.
+
+        Examples
+        --------
+        >>> from pygmt.helpers import GMTTempFile
+        >>> import xarray as xr
+        >>> data = xr.Dataset(
+        ...     coords={"index": [0, 1, 2]},
+        ...     data_vars={
+        ...         "x": ("index", [9, 8, 7]),
+        ...         "y": ("index", [6, 5, 4]),
+        ...         "z": ("index", [3, 2, 1]),
+        ...     },
+        ... )
+        >>> with Session() as ses:
+        ...     with ses.virtualfile_from_data(
+        ...         check_kind="vector", data=data
+        ...     ) as fin:
+        ...         # Send the output to a file so that we can read it
+        ...         with GMTTempFile() as fout:
+        ...             ses.call_module("info", f"{fin} ->{fout.name}")
+        ...             print(fout.read().strip())
+        ...
+        <vector memory>: N = 3 <7/9> <4/6> <1/3>
+        """
+        kind = data_kind(data, x, y, z)
+
+        if check_kind == "raster" and kind not in ("file", "grid"):
+            raise GMTInvalidInput(f"Unrecognized data type for grid: {type(data)}")
+        if check_kind == "vector" and kind not in ("file", "matrix", "vectors"):
+            raise GMTInvalidInput(f"Unrecognized data type: {type(data)}")
+
+        # Decide which virtualfile_from_ function to use
+        _virtualfile_from = {
+            "file": dummy_context,
+            "grid": self.virtualfile_from_grid,
+            # Note: virtualfile_from_matrix is not used because a matrix can be
+            # converted to vectors instead, and using vectors allows for better
+            # handling of string type inputs (e.g. for datetime data types)
+            "matrix": self.virtualfile_from_vectors,
+            "vectors": self.virtualfile_from_vectors,
+        }[kind]
+
+        # Ensure the data is an iterable (Python list or tuple)
+        if kind in ("file", "grid"):
+            _data = (data,)
+        elif kind == "vectors":
+            _data = [np.atleast_1d(x), np.atleast_1d(y)]
+            if z is not None:
+                _data.append(np.atleast_1d(z))
+            if extra_arrays:
+                _data.extend(extra_arrays)
+        elif kind == "matrix":  # turn 2D arrays into list of vectors
+            try:
+                # pandas.DataFrame and xarray.Dataset types
+                _data = [array for _, array in data.items()]
+            except AttributeError:
+                try:
+                    # Just use virtualfile_from_matrix for 2D numpy.ndarray
+                    # which are signed integer (i), unsigned integer (u) or
+                    # floating point (f) types
+                    assert data.ndim == 2 and data.dtype.kind in "iuf"
+                    _virtualfile_from = self.virtualfile_from_matrix
+                    _data = (data,)
+                except (AssertionError, AttributeError):
+                    # Python lists, tuples, and numpy ndarray types
+                    _data = np.atleast_2d(np.asanyarray(data).T)
+
+        # Finally create the virtualfile from the data, to be passed into GMT
+        file_context = _virtualfile_from(*_data)
+
+        return file_context
+
     def extract_region(self):
         """
         Extract the WESN bounding box of the currently active figure.
