@@ -3,19 +3,18 @@ info - Get information about data tables.
 """
 import numpy as np
 from pygmt.clib import Session
-from pygmt.exceptions import GMTInvalidInput
 from pygmt.helpers import (
     GMTTempFile,
     build_arg_string,
-    data_kind,
-    dummy_context,
     fmt_docstring,
+    kwargs_to_strings,
     use_alias,
 )
 
 
 @fmt_docstring
-@use_alias(C="per_column", I="spacing", T="nearest_multiple", V="verbose")
+@use_alias(C="per_column", I="spacing", T="nearest_multiple", V="verbose", f="coltypes")
+@kwargs_to_strings(I="sequence")
 def info(table, **kwargs):
     r"""
     Get information about data tables.
@@ -30,8 +29,8 @@ def info(table, **kwargs):
     and *dy* are needed). If the ``per_column`` parameter is combined with
     ``spacing``, then the numpy.ndarray output will be rounded up/down for as
     many columns as there are increments provided in ``spacing``. A similar
-    parameter ``nearest_multiple`` option will provide a numpy.ndarray in the
-    form of [*zmin*, *zmax*, *dz*]`` for makecpt.
+    parameter ``nearest_multiple`` will provide a numpy.ndarray in the form
+    of [*zmin*, *zmax*, *dz*] for makecpt.
 
     Full option list at :gmt-docs:`gmtinfo.html`
 
@@ -56,6 +55,7 @@ def info(table, **kwargs):
         of dz and output this in the form ``[zmin, zmax, dz]``.
 
     {V}
+    {f}
 
     Returns
     -------
@@ -63,24 +63,11 @@ def info(table, **kwargs):
         Return type depends on whether any of the ``per_column``,
         ``spacing``, or ``nearest_multiple`` parameters are set.
 
-        - np.ndarray if either of the above parameters are used.
+        - :class:`numpy.ndarray` if either of the above parameters are used.
         - str if none of the above parameters are used.
     """
-    kind = data_kind(table)
     with Session() as lib:
-        if kind == "file":
-            file_context = dummy_context(table)
-        elif kind == "matrix":
-            try:
-                # pandas.DataFrame and xarray.Dataset types
-                arrays = [array for _, array in table.items()]
-            except AttributeError:
-                # Python lists, tuples, and numpy ndarray types
-                arrays = np.atleast_2d(np.asanyarray(table).T)
-            file_context = lib.virtualfile_from_vectors(*arrays)
-        else:
-            raise GMTInvalidInput(f"Unrecognized data type: {type(table)}")
-
+        file_context = lib.virtualfile_from_data(data=table)
         with GMTTempFile() as tmpfile:
             with file_context as fname:
                 arg_str = " ".join(
@@ -94,6 +81,10 @@ def info(table, **kwargs):
             # instead of a raw string that is less useful.
             if result.startswith(("-R", "-T")):  # e.g. -R0/1/2/3 or -T0/9/1
                 result = result[2:].replace("/", " ")
-            result = np.loadtxt(result.splitlines())
+            try:
+                result = np.loadtxt(result.splitlines())
+            except ValueError:
+                # Load non-numerical outputs in str type, e.g. for datetime
+                result = np.loadtxt(result.splitlines(), dtype="str")
 
         return result
