@@ -29,6 +29,7 @@ from pygmt.helpers import (
     X="xshift",
     Y="yshift",
     c="panel",
+    f="coltypes",
     p="perspective",
     t="transparency",
 )
@@ -143,6 +144,7 @@ def text_(
     {V}
     {XY}
     {c}
+    {f}
     {p}
     {t}
     """
@@ -165,7 +167,7 @@ def text_(
     if kind == "vectors" and text is None:
         raise GMTInvalidInput("Must provide text with x/y pairs or position")
 
-    # Build the `-F` argument in gmt text.
+    # Build the -F option in gmt text.
     if "F" not in kwargs.keys() and (
         (
             position is not None
