@@ -1,19 +1,21 @@
 """
-Test the behaviors of the Figure class
-Doesn't include the plotting commands, which have their own test files.
+Test the behavior of the Figure class.
+
+Doesn't include the plotting commands which have their own test files.
 """
 import os
 
 import numpy as np
 import numpy.testing as npt
 import pytest
-
-from .. import Figure
-from ..exceptions import GMTInvalidInput
+from pygmt import Figure
+from pygmt.exceptions import GMTInvalidInput
 
 
 def test_figure_region():
-    "Extract the plot region for the figure"
+    """
+    Extract the plot region for the figure.
+    """
     region = [0, 1, 2, 3]
     fig = Figure()
     fig.basemap(region=region, projection="X1id/1id", frame=True)
@@ -21,7 +23,9 @@ def test_figure_region():
 
 
 def test_figure_region_multiple():
-    "Make sure the region argument is for the current figure"
+    """
+    Make sure the region argument is for the current figure.
+    """
     region1 = [-10, 2, 0.355, 67]
     fig1 = Figure()
     fig1.basemap(region=region1, projection="X1id/1id", frame=True)
@@ -34,7 +38,9 @@ def test_figure_region_multiple():
 
 
 def test_figure_region_country_codes():
-    "Extract the plot region for the figure using country codes"
+    """
+    Extract the plot region for the figure using country codes.
+    """
     fig = Figure()
     fig.basemap(region="JP", projection="M3i", frame=True)
     npt.assert_allclose(
@@ -46,9 +52,11 @@ def test_figure_region_country_codes():
 
 
 def test_figure_savefig_exists():
-    "Make sure the saved figure has the right name"
+    """
+    Make sure the saved figure has the right name.
+    """
     fig = Figure()
-    fig.basemap(region="10/70/-300/800", J="X3i/5i", B="af")
+    fig.basemap(region="10/70/-300/800", projection="X3i/5i", frame="af")
     prefix = "test_figure_savefig_exists"
     for fmt in "png pdf jpg bmp eps tif".split():
         fname = ".".join([prefix, fmt])
@@ -57,10 +65,25 @@ def test_figure_savefig_exists():
         os.remove(fname)
 
 
-def test_figure_savefig_transparent():
-    "Check if fails when transparency is not supported"
+def test_figure_savefig_unknown_extension():
+    """
+    Check that an error is raised when an unknown extension is passed.
+    """
     fig = Figure()
-    fig.basemap(region="10/70/-300/800", J="X3i/5i", B="af")
+    fig.basemap(region="10/70/-300/800", projection="X3i/5i", frame="af")
+    prefix = "test_figure_savefig_unknown_extension"
+    fmt = "test"
+    fname = ".".join([prefix, fmt])
+    with pytest.raises(GMTInvalidInput):
+        fig.savefig(fname)
+
+
+def test_figure_savefig_transparent():
+    """
+    Check if fails when transparency is not supported.
+    """
+    fig = Figure()
+    fig.basemap(region="10/70/-300/800", projection="X3i/5i", frame="af")
     prefix = "test_figure_savefig_transparent"
     for fmt in "pdf jpg bmp eps tif".split():
         fname = ".".join([prefix, fmt])
@@ -74,11 +97,15 @@ def test_figure_savefig_transparent():
 
 
 def test_figure_savefig():
-    "Check if the arguments being passed to psconvert are correct"
+    """
+    Check if the arguments being passed to psconvert are correct.
+    """
     kwargs_saved = []
 
     def mock_psconvert(*args, **kwargs):  # pylint: disable=unused-argument
-        "Just record the arguments"
+        """
+        Just record the arguments.
+        """
         kwargs_saved.append(kwargs)
 
     fig = Figure()
@@ -110,22 +137,40 @@ def test_figure_savefig():
 
 
 def test_figure_show():
-    "Test that show creates the correct file name and deletes the temp dir"
+    """
+    Test that show creates the correct file name and deletes the temp dir.
+    """
     fig = Figure()
-    fig.basemap(R="10/70/-300/800", J="X3i/5i", B="af")
+    fig.basemap(region="10/70/-300/800", projection="X3i/5i", frame="af")
     img = fig.show(width=800)
     assert img.width == 800
 
 
 @pytest.mark.mpl_image_compare
 def test_shift_origin():
-    "Test if fig.shift_origin works"
+    """
+    Test if fig.shift_origin works.
+    """
     fig = Figure()
-    fig.basemap(R="10/70/-300/300", J="X3i/5i", B="af")
+    # First call shift_origin without projection and region.
+    # Test the issue https://github.com/GenericMappingTools/pygmt/issues/514
+    fig.shift_origin(xshift="2i", yshift="3i")
+    fig.basemap(region="10/70/-300/300", projection="X3i/5i", frame="af")
     fig.shift_origin(xshift="4i")
-    fig.basemap(R="10/70/-300/300", J="X3i/5i", B="af")
+    fig.basemap(region="10/70/-300/300", projection="X3i/5i", frame="af")
     fig.shift_origin(yshift="6i")
-    fig.basemap(R="10/70/-300/300", J="X3i/5i", B="af")
+    fig.basemap(region="10/70/-300/300", projection="X3i/5i", frame="af")
     fig.shift_origin(xshift="-4i", yshift="6i")
-    fig.basemap(R="10/70/-300/300", J="X3i/5i", B="af")
+    fig.basemap(region="10/70/-300/300", projection="X3i/5i", frame="af")
     return fig
+
+
+def test_figure_show_invalid_method():
+    """
+    Test to check if an error is raised when an invalid method is passed to
+    show.
+    """
+    fig = Figure()
+    fig.basemap(region="10/70/-300/800", projection="X3i/5i", frame="af")
+    with pytest.raises(GMTInvalidInput):
+        fig.show(method="test")
